@@ -78,7 +78,7 @@ yelp_doc_info_new (const gchar *uri)
     YelpDocInfo *doc;
     gchar       *doc_uri  = NULL;
     gchar       *full_uri = NULL;
-    YelpDocType  doc_type;
+    YelpDocType  doc_type = YELP_DOC_TYPE_ERROR;
     YelpURIType  uri_type;
     gchar *cur;
 
@@ -121,6 +121,11 @@ yelp_doc_info_new (const gchar *uri)
 	doc_type = YELP_DOC_TYPE_TOC;
 	uri_type = YELP_URI_TYPE_TOC;
     }
+    else if (g_str_has_prefix (full_uri, "x-yelp-search:")) {
+	doc_uri = g_strconcat ("file://" DATADIR "/yelp/xslt/search2html.xsl?", full_uri + strlen ("x-yelp-search:"), NULL);
+	doc_type = YELP_DOC_TYPE_SEARCH;
+	uri_type = YELP_URI_TYPE_SEARCH;
+    }
     else {
 	doc_uri = g_strdup (uri);
 	doc_type = YELP_DOC_TYPE_EXTERNAL;
@@ -184,7 +189,7 @@ yelp_doc_info_get (const gchar *uri)
     if (!doc) {
 	doc = yelp_doc_info_new (doc_uri);
 	if (doc && doc->type != YELP_DOC_TYPE_EXTERNAL) {
-	    YelpDocInfo *old_doc;
+	    YelpDocInfo *old_doc = NULL;
 
 	    for (i = 0; i < doc->num_uris; i++) {
 		old_doc = g_hash_table_lookup (doc_info_table,
